CommonCode
==========

- license: Apache-2.0
- copyright: copyright (c) nexB. Inc. and others
- homepage_url: https://github.com/nexB/commoncode
- keywords: utilities, scancode-toolkit, commoncode

Commoncode provides a set of common functions and utilities for handling various things like paths,
dates, files and hashes. It started as library in scancode-toolkit.
Visit https://aboutcode.org and https://github.com/nexB/ for support and download.


To install this package use::

    pip install commoncode


Alternatively, to set up a development environment::

    source configure --dev

To run unit tests::

    pytest -vvs -n 2

To clean up development environment::

    ./configure --clean

